@@ -374,7 +374,7 @@ class Tado:
 
         data = self._apiCall(cmd, "PUT", post_data)
 
-        _LOGGER.debug(data)
+        _LOGGER.error(data)
         return data
         
     def getZoneOverlayDefault(self, zone):
